import 'package:equatable/equatable.dart';
import 'package:furima_item_search/fs_query_condition.dart';
import 'package:furima_item_search/fs_site.dart';

class FSQuery extends Equatable {
  FSQuery(
      {this.id,
      this.keyword,
      this.deliveryType,
      this.saleStatus,
      this.sites,
      this.sortOrder,
      this.priceMin,
      this.priceMax,
      this.isEnabled})
      : super([
          id,
          keyword,
          deliveryType,
          saleStatus,
          sites,
          sortOrder,
          priceMin,
          priceMax,
          isEnabled
        ]);

  int id;
  String keyword;
  FSDeliveryType deliveryType;
  FSSaleStatus saleStatus;
  List<FSSite> sites;
  FSSortOrder sortOrder;
  int priceMin;
  int priceMax;
  bool isEnabled;

  factory FSQuery.initial() {
    return FSQuery(
        keyword: '',
        deliveryType: FSDeliveryType.all,
        saleStatus: FSSaleStatus.all,
        sites: FSSite.values,
        sortOrder: FSSortOrder.recommended,
        priceMin: -1,
        priceMax: -1,
        isEnabled: false);
  }

  FSQuery copyWith(
      {String keyword,
      FSDeliveryType deliveryType,
      FSSaleStatus saleStatus,
      List<FSSite> sites,
      FSSortOrder sortOrder,
      int priceMin,
      int priceMax,
      bool isEnabled}) {
    return FSQuery(
      id: this.id,
      keyword: keyword ?? this.keyword,
      deliveryType: deliveryType ?? this.deliveryType,
      saleStatus: saleStatus ?? this.saleStatus,
      sites: sites ?? this.sites,
      sortOrder: sortOrder ?? this.sortOrder,
      priceMin: priceMin ?? this.priceMin,
      priceMax: priceMax ?? this.priceMax,
      isEnabled: isEnabled ?? this.isEnabled,
    );
  }

  bool get isRegistered {
    return id != null;
  }

  String get priceText {
    if (priceMin < 0 && priceMax < 0) {
      return "";
    } else {
      String priceText = '￥ ';
      if (priceMin >= 0) {
        priceText += priceMin.toString();
      }
      priceText += ' 〜 ';
      if (priceMax >= 0) {
        priceText += priceMax.toString();
      }
      return priceText;
    }
  }

  String parameter(FSSite site) {
    String parameter;
    switch (site) {
      case FSSite.mercari:
        parameter = 'keyword=' + keyword.trim().replaceAll(' ', '+');
        if (priceMin >= 0) {
          parameter += '&price_min=' + priceMin.toString();
        }
        if (priceMax >= 0) {
          parameter += '&price_max=' + priceMax.toString();
        }
        break;
      case FSSite.rakuma:
        parameter = 'query=' + keyword.trim();
        if (priceMin >= 0) {
          parameter += '&min=' + priceMin.toString();
        }
        if (priceMax >= 0) {
          parameter += '&max=' + priceMax.toString();
        }
        break;
      case FSSite.yahoo:
        parameter =
            'price_type=currentprice&p=' + keyword.trim().replaceAll(' ', '+');
        if (priceMin >= 0) {
          parameter += '&min=' + priceMin.toString();
        }
        if (priceMax >= 0) {
          parameter += '&max=' + priceMax.toString();
        }
        break;
    }
    parameter += SaleStatusHelper.parameter(site, saleStatus) +
        DeliveryTypeHelper.parameter(site, deliveryType) +
        SortOrderHelper.parameter(site, sortOrder);
    return parameter;
  }
}
