import 'package:furima_item_search/fs_site.dart';

enum FSSaleStatus { all, onSale, sole }

class SaleStatusHelper {
  static String getName(FSSaleStatus saleStatus) {
    switch (saleStatus) {
      case FSSaleStatus.all:
        return 'すべて';
      case FSSaleStatus.onSale:
        return '販売中のみ';
      case FSSaleStatus.sole:
        return '売切れのみ';
    }
  }

  static String parameter(FSSite site, FSSaleStatus saleStatus) {
    switch (site) {
      case FSSite.mercari:
        switch (saleStatus) {
          case FSSaleStatus.all:
            return '&status_all=1';
          case FSSaleStatus.onSale:
            return '&status_on_sale=1';
          case FSSaleStatus.sole:
            return '&status_trading_sold_out=1';
        }
        break;
      case FSSite.rakuma:
        switch (saleStatus) {
          case FSSaleStatus.all:
            return '';
          case FSSaleStatus.onSale:
            return '&transaction=selling';
          case FSSaleStatus.sole:
            return '&transaction=soldout';
        }
        break;
      default:
        return '';
    }
  }
}

enum FSDeliveryType { all, included }

class DeliveryTypeHelper {
  static String getName(FSDeliveryType type) {
    switch (type) {
      case FSDeliveryType.all:
        return 'すべて';
      case FSDeliveryType.included:
        return '送料込みのみ';
    }
  }

  static String parameter(FSSite site, FSDeliveryType type) {
    switch (site) {
      case FSSite.mercari:
        switch (type) {
          case FSDeliveryType.all:
            return '&shipping_payer_all=1';
          case FSDeliveryType.included:
            return '&shipping_payer_id%5B2%5D=1';
        }
        break;
      case FSSite.rakuma:
        switch (type) {
          case FSDeliveryType.all:
            return '';
          case FSDeliveryType.included:
            return '&carriage=1';
        }
        break;
      default:
        return '';
    }
  }
}

enum FSSortOrder {
  recommended,
  priceDesc,
  priceAsc,
  createdDesc,
  likeCountDesc
}

class SortOrderHelper {
  static String getName(FSSortOrder type) {
    switch (type) {
      case FSSortOrder.recommended:
        return 'おすすめ順';
      case FSSortOrder.priceAsc:
        return '安い順';
      case FSSortOrder.priceDesc:
        return '高い順';
      case FSSortOrder.createdDesc:
        return '新着順';
      case FSSortOrder.likeCountDesc:
        return 'いいねの多い順';
    }
  }

  static String parameter(FSSite site, FSSortOrder sortOrder) {
    switch (site) {
      case FSSite.mercari:
        switch (sortOrder) {
          case FSSortOrder.recommended:
            return '&sort_order=';
          case FSSortOrder.priceAsc:
            return '&sort_order=price_asc';
          case FSSortOrder.priceDesc:
            return '&sort_order=price_desc';
          case FSSortOrder.likeCountDesc:
            return '&sort_order=like_desc';
          case FSSortOrder.createdDesc:
            return '&sort_order=created_desc';
        }
        break;
      case FSSite.rakuma:
        switch (sortOrder) {
          case FSSortOrder.recommended:
            return '&sort=relevance&order=desc';
          case FSSortOrder.priceAsc:
            return '&sort=sell_price&order=asc';
          case FSSortOrder.priceDesc:
            return '&sort=sell_price&order=desc';
          case FSSortOrder.likeCountDesc:
            return '&sort=like_count&order=desc';
          case FSSortOrder.createdDesc:
            return '&sort=item_id&order=desc';
        }
        break;
      case FSSite.yahoo:
        switch (sortOrder) {
          case FSSortOrder.recommended:
            return '&s1=score2&o1=d';
          case FSSortOrder.priceAsc:
            return '&s1=cbids&o1=a';
          case FSSortOrder.priceDesc:
            return '&s1=cbids&o1=d';
          case FSSortOrder.likeCountDesc:
            return '&s1=bids&o1=d';
          case FSSortOrder.createdDesc:
            return '&s1=new&o1=d';
        }
        break;
    }
  }
}
